JSON API
~~~~~~~~

This page documents the JSON API provided by `cubicweb-jsonschema` under the
``application/json`` content type.


.. include:: entities.rst
.. include:: entity.rst
.. include:: relationships.rst
